/**
 * EasyBeans
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: HandlerChain.java 4642 2009-02-19 10:40:57Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl.xml.struct;

import org.ow2.util.ee.metadata.common.api.xml.struct.IHandlerChain;
import org.ow2.util.ee.metadata.common.api.xml.struct.IHandler;

import javax.xml.namespace.QName;
import java.util.List;
import java.util.ArrayList;

/**
 * The HandlerChain is the representant of the XML element <code>handler-chain</code>
 *
 * @author Guillaume Sauthier
 */
public class HandlerChain implements IHandlerChain {

    /**
     * Pattern matching service name.
     */
    private QName serviceNamePattern;

    /**
     * Pattern matching port name.
     */
    private QName portNamePattern;

    /**
     * List of requested protocol bindings ID.
     */
    private List<String> protocolBindings = new ArrayList<String>();

    /**
     * List of handlers cpomposing this chain.
     */
    private List<IHandler> handlers = new ArrayList<IHandler>();

    /**
     * @return a QName representing a pattern for matching a service name.
     */
    public QName getServiceNamePattern() {
        return serviceNamePattern;
    }

    public void setServiceNamePattern(QName serviceNamePattern) {
        this.serviceNamePattern = serviceNamePattern;
    }

    /**
     * @return a QName representing a pattern for matching a port name.
     */
    public QName getPortNamePattern() {
        return portNamePattern;
    }

    public void setPortNamePattern(QName portNamePattern) {
        this.portNamePattern = portNamePattern;
    }

    /**
     * @return a list of protocol bindings IDs
     */
    public List<String> getProtocolBindings() {
        return protocolBindings;
    }

    public void addProtocolBinding(String binding) {
        this.protocolBindings.add(binding);
    }

    /**
     * @return the list of <code>handler</code> composing this chain.
     */
    public List<IHandler> getHandlers() {
        return handlers;
    }

    public void addHandler(IHandler handler) {
        this.handlers.add(handler);
    }
}
