/**
 * EasyBeans
 * Copyright (C) 2008-2009 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ServiceRef.java 4642 2009-02-19 10:40:57Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl.xml.struct;

import java.net.URI;
import java.util.ArrayList;
import java.util.List;

import javax.xml.namespace.QName;

import org.ow2.util.ee.metadata.common.api.xml.struct.IPortComponentRef;
import org.ow2.util.ee.metadata.common.api.xml.struct.IServiceRef;
import org.ow2.util.ee.metadata.common.api.xml.struct.IHandlerChains;

/**
 * Class representing service-ref elements used in Java EE components.
 * @author Guillaume Sauthier
 */
public class ServiceRef extends AbsResourceGroup implements IServiceRef {
    /**
     * Name of this service-ref.
     */
    private String name;

    /**
     * Interface of the service. (javax.xml.rpc.Service or javax.xml.ws.Service)
     */
    private String serviceInterface;

    /**
     * Type of this service-ref.
     */
    private String serviceRefType;

    /**
     * WSDL file (relative to the root of this module).
     */
    private URI wsdlFile;

    /**
     * Name of the wsdl:service element refered to.
     */
    private QName serviceQName;

    /**
     * List of this service's port-components.
     */
    private List<IPortComponentRef> portComponentRefList;

    /**
     * the handler-chains.
     */
    private IHandlerChains handlerChains = null;

    /**
     * Constructs an empty ServiceRef element.
     */
    public ServiceRef() {
        portComponentRefList = new ArrayList<IPortComponentRef>();
    }

    public String getName() {
        return name;
    }

    public void setName(final String name) {
        this.name = name;
    }

    public String getServiceInterface() {
        return serviceInterface;
    }

    public void setServiceInterface(final String serviceInterface) {
        this.serviceInterface = serviceInterface;
    }

    public QName getServiceQName() {
        return serviceQName;
    }

    public void setServiceQName(final QName serviceQName) {
        this.serviceQName = serviceQName;
    }

    public String getServiceRefType() {
        return serviceRefType;
    }

    public void setServiceRefType(final String serviceRefType) {
        this.serviceRefType = serviceRefType;
    }

    public URI getWsdlFile() {
        return wsdlFile;
    }

    public void setWsdlFile(final URI wsdlFile) {
        this.wsdlFile = wsdlFile;
    }

    public void addPortComponentRef(final IPortComponentRef portComponentRef) {
        portComponentRefList.add(portComponentRef);
    }

    public List<IPortComponentRef> getPortComponentRefList() {
        return portComponentRefList;
    }

    public void setHandlerChains(final IHandlerChains handlerChains) {
        this.handlerChains = handlerChains;
    }

    public IHandlerChains getHandlerChains() {
        return handlerChains;
    }
}
